@@ -2,7 +2,7 @@ app <- ShinyDriver$new("../", seed = 1)
 app$snapshotInit("3dimBranin")
 
 app$setInputs(objectiveFunction = "rEnv")
-app$setInputs(funName = "branin")
+app$setInputs(funName = "funBranin")
 app$setInputs(addDimension = "click")
 app$setInputs(addDimension = "click")
 app$setInputs(dimensionType2 = "integer")
@@ -12,6 +12,7 @@ app$setInputs(dimensionAmount2 = 2)
 app$setInputs(lowerBound3 = -3)
 app$setInputs(upperBound3 = 3)
 app$setInputs(tabs = "spotConfig")
+Sys.sleep(2)
 app$setInputs(tabs = "runMode")
 app$setInputs(runSpotIter = "click")
 app$setInputs(tabs = "spotConfig")
@@ -19,5 +20,5 @@ app$setInputs(tabs = "runMode")
 app$setInputs(proposeNewPoint = "click")
 app$setInputs(evaluateData = "click")
 app$setInputs(runSpotIter = "click")
-Sys.sleep(5)
+Sys.sleep(10)
 app$snapshot(list(output = "resultTable"))
