@@ -2,7 +2,7 @@ app <- ShinyDriver$new("../", seed = 1)
 app$snapshotInit("testBranin_RF_LBFGSB_UR")
 
 app$setInputs(objectiveFunction = "rEnv")
-app$setInputs(funName = "branin")
+app$setInputs(funName = "funBranin")
 app$setInputs(addDimension = "click")
 app$setInputs(addDimension = "click")
 app$setInputs(dimensionType2 = "integer")
@@ -25,4 +25,5 @@ app$setInputs(proposeNewPoint = "click")
 app$setInputs(evaluateData = "click")
 app$setInputs(proposeNewPoint = "click")
 app$setInputs(evaluateData = "click")
+Sys.sleep(2)
 app$snapshot(list(output = "resultTable"))
