@@ -11,7 +11,8 @@ app$setInputs(tabs = "spotConfig")
 app$setInputs(tabs = "runMode")
 app$setInputs(runSpotIter = "click")
 app$setInputs(tabs = "objectiveFunction")
-app$setInputs(funName = "branin")
+app$setInputs(tabs = "objectiveFunction")
+app$setInputs(funName = "funBranin")
 app$setInputs(tabs = "spotConfig")
 app$setInputs(tabs = "runMode")
 app$setInputs(runSpotIter = "click")
