@@ -9,7 +9,7 @@ app$setInputs(tabs = "spotConfig")
 app$setInputs(tabs = "runMode")
 app$setInputs(runCreateDOE = "click")
 app$setInputs(tabs = "objectiveFunction")
-app$setInputs(funName = "branin")
+app$setInputs(funName = "funBranin")
 app$setInputs(tabs = "spotConfig")
 app$setInputs(tabs = "runMode")
 app$setInputs(runCreateDOE = "click")
@@ -17,4 +17,5 @@ app$setInputs(tabs = "objectiveFunction")
 app$setInputs(funName = "fakeFunctionForTesting")
 app$setInputs(tabs = "runMode")
 app$setInputs(evaluateData = "click")
+Sys.sleep(2)
 app$snapshot(list(output = "resultTable"))
